<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>CollectionSetupModel</name>
    <message>
        <location filename="../src/collectionsetupmodel.cpp" line="97"/>
        <source>Select folders for music collection</source>
        <translation>Válassz mappákat a gyüjteményhez</translation>
    </message>
</context>
<context>
    <name>CollectionTree</name>
    <message>
        <location filename="../src/collectiontree.cpp" line="56"/>
        <location filename="../src/collectiontree.cpp" line="128"/>
        <location filename="../src/collectiontree.cpp" line="358"/>
        <source>Artist</source>
        <translation>Előadó</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="106"/>
        <location filename="../src/collectiontree.cpp" line="360"/>
        <source>Genre</source>
        <translation>Műfaj</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="117"/>
        <location filename="../src/collectiontree.cpp" line="361"/>
        <source>Year</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="321"/>
        <source>Add to PlayList&amp;1</source>
        <translation>&amp;1-es lejátszólistához</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="323"/>
        <source>Add to PlayList&amp;2</source>
        <translation>&amp;2-es lejátszólistához</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="326"/>
        <source>Re-scan collection</source>
        <translation>Gyüjtemény frissítése</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="357"/>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="359"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="362"/>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="365"/>
        <source>Meta Information</source>
        <translation>Meta adatok</translation>
    </message>
</context>
<context>
    <name>CollectionTreeItem</name>
    <message>
        <location filename="../src/collectiontreeitem.cpp" line="97"/>
        <source>All</source>
        <translation type="unfinished">minden</translation>
    </message>
</context>
<context>
    <name>CollectionWidget</name>
    <message>
        <source>yy</source>
        <translation type="obsolete">Év</translation>
    </message>
    <message>
        <location filename="../src/collectionwidget.cpp" line="61"/>
        <source>Random Tracks</source>
        <translation>Véletlenszerű lejátszás</translation>
    </message>
    <message>
        <location filename="../src/collectionwidget.cpp" line="64"/>
        <source>Enter space-separated terms to filter collection</source>
        <translation>Szóközzel elválasztott kifejezések a gyüjtemény szűréséhez</translation>
    </message>
</context>
<context>
    <name>Core::Internal::FancyTabWidget</name>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="646"/>
        <source>Large sidebar</source>
        <translation>Nagy oldalsáv</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="647"/>
        <source>Small sidebar</source>
        <translation>Kis oldalsáv</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="648"/>
        <source>Plain sidebar</source>
        <translation>Egyszerű oldalsáv</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="649"/>
        <source>Tabs on top</source>
        <translation>Lapok felül</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="650"/>
        <source>Icons on top</source>
        <translation>Ikonok felül</translation>
    </message>
</context>
<context>
    <name>DjBrowser</name>
    <message>
        <location filename="../src/djbrowser.cpp" line="69"/>
        <source>Add a new AutoDj</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djbrowser.cpp" line="80"/>
        <source>Add a new record case for current AutoDj</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DjFilterWidget</name>
    <message>
        <location filename="../src/djfilterwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="354"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="214"/>
        <source>Record Case</source>
        <translation>Lemezborító</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1192"/>
        <source>Remove this record case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1195"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1685"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#e1e1e1;&quot;&gt;Path&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#e1e1e1;&quot;&gt;Útvonal&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="331"/>
        <location filename="../src/djfilterwidget.ui" line="388"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1142"/>
        <source>Activate this record case</source>
        <translation>Lemezborító aktiválása</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1145"/>
        <source>set</source>
        <translatorcomment>beállítások is over long</translatorcomment>
        <translation>set</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1148"/>
        <source>Alt+J</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1172"/>
        <source>Count</source>
        <translation>Szám</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2664"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2676"/>
        <source>Delete</source>
        <translation type="unfinished">töröl</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="452"/>
        <source>how many records per turn</source>
        <translation>Hány felvétel fordulónként</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="obsolete">Útvonal</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2167"/>
        <source>Genre</source>
        <translation>Műfaj</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2617"/>
        <source>Artist</source>
        <translation>Előadó</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="320"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;count of records which fit to this filter(s)&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;szűrőnek megfelelő felvételek száma&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>?</source>
        <translation type="obsolete">?</translation>
    </message>
    <message>
        <source>select directory</source>
        <translation type="obsolete">Válassz mappát</translation>
    </message>
    <message>
        <source>^</source>
        <translation type="obsolete">^</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.cpp" line="157"/>
        <location filename="../src/djfilterwidget.cpp" line="203"/>
        <source>of</source>
        <translation>a</translation>
    </message>
</context>
<context>
    <name>DjSettings</name>
    <message>
        <location filename="../src/djsettings.ui" line="26"/>
        <source>Form</source>
        <translation type="unfinished">Form</translation>
    </message>
    <message>
        <location filename="../src/djsettings.ui" line="47"/>
        <source>0</source>
        <translation type="unfinished">0</translation>
    </message>
</context>
<context>
    <name>DjWidget</name>
    <message>
        <location filename="../src/djwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="100"/>
        <source>AutoDJ</source>
        <translation type="unfinished">AutoDJ</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="137"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="208"/>
        <source>Start a session of this DJ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="222"/>
        <source>Remove this DJ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="225"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="281"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="290"/>
        <source>Delete</source>
        <translation type="unfinished">töröl</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;fdadfaf&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;fdadfaf&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="253"/>
        <source>TextLabel</source>
        <translation>Szövegcimke</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="139"/>
        <source>tracks</source>
        <translation type="unfinished">Sáv</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="140"/>
        <source>hours</source>
        <translation type="unfinished">Óra</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="136"/>
        <source>cases</source>
        <translation type="unfinished">Eset</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="135"/>
        <source>This Dj plays: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="136"/>
        <source>case</source>
        <translation type="unfinished">Eset</translation>
    </message>
</context>
<context>
    <name>Knowthelist</name>
    <message>
        <location filename="../src/knowthelist.ui" line="14"/>
        <source>Knowthelist</source>
        <translation>Knowthelist</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1141"/>
        <source>Fader</source>
        <translation>Fader</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1836"/>
        <source>AutoD&amp;J</source>
        <translation>AutoD&amp;J</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1839"/>
        <location filename="../src/knowthelist.ui" line="5724"/>
        <source>Alt+J</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="2499"/>
        <source>Set</source>
        <translatorcomment>Beállítások over long</translatorcomment>
        <translation>Set</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="4845"/>
        <source>FadeNo&amp;w</source>
        <translation>Fade mos&amp;t</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="4848"/>
        <source>Alt+W</source>
        <translation>Alt+T</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5096"/>
        <location filename="../src/knowthelist.ui" line="5777"/>
        <source>Gain</source>
        <translation>Hangerő</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5721"/>
        <source>AGC</source>
        <translation>AGC</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5798"/>
        <location filename="../src/knowthelist.ui" line="5822"/>
        <source>Low</source>
        <translation>Mély</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5843"/>
        <location filename="../src/knowthelist.ui" line="5867"/>
        <source>Mid</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5891"/>
        <location filename="../src/knowthelist.ui" line="5915"/>
        <source>High</source>
        <translation>Magas</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7559"/>
        <source>MonitorPlayer</source>
        <translation>Lejátszóeszköz</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="6890"/>
        <source>0:00.0</source>
        <translation>0:00.0</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7615"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;settings&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#df0000;&quot;&gt;No 2nd soundcard selected!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;settings&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#df0000;&quot;&gt;Nincs második hangkártya&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7192"/>
        <source>-0:00.0</source>
        <translation>-0:00.0</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7640"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="188"/>
        <source>Collection</source>
        <translation>Gyüjtemény</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="252"/>
        <source>AutoDJ</source>
        <translation>AutoDJ</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="260"/>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="285"/>
        <source>Lists</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeSelector</name>
    <message>
        <location filename="../src/modeselector.ui" line="31"/>
        <source>Frame</source>
        <translatorcomment>no need to translate</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="70"/>
        <source>View: Artist &gt; Album</source>
        <translation>látvány: Előadó &gt; Album </translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="101"/>
        <source>View: Year &gt; Artist &gt; Album</source>
        <translation>látvány: Év &gt; Előadó &gt; Album</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="104"/>
        <source>Y</source>
        <translation>É</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="132"/>
        <source>View: Genre &gt; Artist &gt; Album</source>
        <translation>látvány: Műfaj &gt; Előadó &gt; Album</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="135"/>
        <source>G</source>
        <translation>M</translation>
    </message>
</context>
<context>
    <name>PlayerWidget</name>
    <message>
        <location filename="../src/playerwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="754"/>
        <source>texttexttextt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="855"/>
        <source>TextLabel</source>
        <translation type="unfinished">Szövegcimke</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="1351"/>
        <source>00:00</source>
        <translation>00:00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2294"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Time remain&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="3048"/>
        <source>Jump to the point where the music starts mainly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cueval</source>
        <translation type="obsolete">Cueval</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="1809"/>
        <location filename="../src/playerwidget.ui" line="2758"/>
        <source>.00</source>
        <translation>.00</translation>
    </message>
    <message>
        <source>texttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttext</source>
        <translation type="obsolete">texttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttexttext</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2300"/>
        <source>-00:00</source>
        <translation>-00:00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2789"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Seconds of silence at the end &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2795"/>
        <source>-00</source>
        <translation type="unfinished">-00</translation>
    </message>
    <message>
        <source>Cue</source>
        <translation>Jel</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="127"/>
        <source>Tracks</source>
        <translation type="unfinished">Sáv</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="127"/>
        <source>Track</source>
        <translation type="unfinished">Sáv</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="132"/>
        <source>Hours</source>
        <translation type="unfinished">óra</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="354"/>
        <source>No track</source>
        <translation type="unfinished">Nincs sáv</translation>
    </message>
</context>
<context>
    <name>Playlist</name>
    <message>
        <source>Trackname</source>
        <translation type="obsolete">Sáv</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <location filename="../src/playlist.cpp" line="1043"/>
        <source>Artist</source>
        <translation>Előadó</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <location filename="../src/playlist.cpp" line="1042"/>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1044"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1046"/>
        <source>Year</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="73"/>
        <source>Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="obsolete">Megjegyzés</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1045"/>
        <source>Genre</source>
        <translation>Műfaj</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <source>Track</source>
        <translation>Sáv</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="obsolete">Könyvtár</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="73"/>
        <source>Length</source>
        <translation>Hossz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation type="obsolete">Bitráta</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="973"/>
        <source>Add to PlayList&amp;1</source>
        <translation>&amp;1-es lejátszólistához</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="975"/>
        <source>Add to PlayList&amp;2</source>
        <translation>&amp;2-es lejátszólistához</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="979"/>
        <source>&amp;Load</source>
        <translation>Betö&amp;ltés</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="982"/>
        <source>Load as &amp;Next</source>
        <translation>Betöltés következő&amp;nek</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="985"/>
        <source>&amp;Prelisten Track</source>
        <translation>&amp;Szám előnézet</translation>
    </message>
    <message>
        <source>&amp;View Tag Information...</source>
        <translation type="obsolete">&amp;Tag információk...</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="988"/>
        <source>&amp;Search for: &apos;%1&apos;</source>
        <translation>&amp;Keresés erre:&apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="992"/>
        <source>&amp;Remove Selected</source>
        <translation>&amp;Kiválasztott törlése</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="994"/>
        <source>&amp;Open File Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="996"/>
        <source>&amp;View Tag Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="1047"/>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="1050"/>
        <source>Meta Information</source>
        <translation>Meta adatok</translation>
    </message>
</context>
<context>
    <name>PlaylistBrowser</name>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="59"/>
        <source>Add a new list and store current tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="118"/>
        <source>Top Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="120"/>
        <source>Most played tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="133"/>
        <source>Last Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="135"/>
        <source>Recently played tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="148"/>
        <source>Favorites Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="150"/>
        <source>High rated tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="174"/>
        <source>tracks</source>
        <translation type="unfinished">Sáv</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="175"/>
        <source>hours</source>
        <translation type="unfinished">Óra</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="313"/>
        <source>Save Play List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="314"/>
        <source>Enter a name for the new list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistWidget</name>
    <message>
        <location filename="../src/playlistwidget.ui" line="14"/>
        <source>Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="111"/>
        <source>Click here to show the content of this list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="114"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;charts&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;Most Played&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="137"/>
        <source>TextLabel</source>
        <translation type="unfinished">Szövegcimke</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="209"/>
        <source>Load all tracks of this list directly into player playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="236"/>
        <source>Remove this list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="239"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="273"/>
        <source>Delete</source>
        <translation type="unfinished">töröl</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="65"/>
        <location filename="../src/main.cpp" line="68"/>
        <source>Unable to load database</source>
        <translation>Adatbázis nem tölthető be</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="66"/>
        <source>This application needs the QT5 SQLITE driver (libqt5-sql-sqlite)</source>
        <translation type="unfinished">Ehhez az alkalmazáshoz szükséges a QT4 SQLITE driver (libqt4-sql-sqlite) {5 ?} {5-?}</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="69"/>
        <source>This application needs the QT4 SQLITE driver (libqt4-sql-sqlite)</source>
        <translation>Ehhez az alkalmazáshoz szükséges a QT4 SQLITE driver (libqt4-sql-sqlite)</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="52"/>
        <location filename="../src/playlistitem.cpp" line="53"/>
        <location filename="../src/playlistitem.cpp" line="80"/>
        <location filename="../src/playlistitem.cpp" line="122"/>
        <location filename="../src/playlistitem.cpp" line="135"/>
        <location filename="../src/track.cpp" line="134"/>
        <location filename="../src/track.cpp" line="135"/>
        <location filename="../src/track.cpp" line="136"/>
        <location filename="../src/track.cpp" line="138"/>
        <location filename="../src/track.cpp" line="146"/>
        <location filename="../src/track.cpp" line="244"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="65"/>
        <source>Title</source>
        <translation type="unfinished">Cím</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="66"/>
        <source>Artist</source>
        <translation type="unfinished">Előadó</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="67"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="68"/>
        <source>Genre</source>
        <translation type="unfinished">Műfaj</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="69"/>
        <source>Year</source>
        <translation type="unfinished">Év</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="70"/>
        <source>Location</source>
        <translation type="unfinished">Hely</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.ui" line="20"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>New Row</source>
        <translation type="obsolete">Új sor</translation>
    </message>
    <message>
        <source>Neue Zeile</source>
        <translation type="obsolete">Neue Zeile</translation>
    </message>
    <message>
        <source>New Column</source>
        <translation type="obsolete">Új oszlop</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="141"/>
        <source>Fader</source>
        <translation>Fader</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="146"/>
        <source>Collection</source>
        <translation>Gyüjtemény</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="151"/>
        <source>Audio devices</source>
        <translation>Audio eszközök</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="156"/>
        <source>AutoDJ</source>
        <translation>AutoDJ</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="161"/>
        <source>Playlists</source>
        <translation>Lejátszólisták</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="166"/>
        <source>File browser</source>
        <translation>Fájlböngésző</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="171"/>
        <source>Common</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="198"/>
        <source>Fader settings</source>
        <translation>Fader beállítások</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="236"/>
        <source>Start fading before song end</source>
        <translation>Halkítás indítása a szám vége előtt</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="265"/>
        <location filename="../src/settingsdialog.ui" line="291"/>
        <source>12s</source>
        <translation>12s</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="278"/>
        <source>Fader Time</source>
        <translation>Lehalkítás hossza</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="326"/>
        <source>Skip silent at start (AutoCue)</source>
        <translation>Csend kihagyása kezdésnél (AutoCue)</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="342"/>
        <source>Skip silent at the end</source>
        <translation>Csend kihagyása a szám végénél</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="374"/>
        <source>Scan for new files and update the music collection</source>
        <translation>Új fájlok keresése és a gyüjtemény frissítése</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="377"/>
        <source>Watch folders for changes</source>
        <translation>Mappák változásának figyelése</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="399"/>
        <source>Scan Now</source>
        <translation>Keresés most</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="406"/>
        <source>Scan folders for songs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="413"/>
        <source>Play Counter Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="420"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="442"/>
        <source>Monitor Player</source>
        <translation>Lejátszóeszköz</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="465"/>
        <source>Device Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="496"/>
        <source>AutoDJ settings</source>
        <translation>AutoDJ beállítások</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="538"/>
        <source>Minimum tracks within each playlist </source>
        <translation>Minimum sáv</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="717"/>
        <source>File Browser Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="794"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="807"/>
        <source>Common Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="841"/>
        <source>Change the language of the application (needs restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="867"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum Tracks</source>
        <translation type="obsolete">Minimum sáv</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="564"/>
        <source>DJ Count</source>
        <translation>DJ számláló</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="596"/>
        <source>DJ Names</source>
        <translation>DJ név</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="609"/>
        <source>Filter Count</source>
        <translation type="unfinished">szűrő számláló</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="622"/>
        <source>Increment play counter for AutoDj selected tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="653"/>
        <source>Auto Remove Played Tracks</source>
        <translation>Lejátszott sávok automatikus eltávolítása</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="666"/>
        <source>Playlist Settings</source>
        <translation>Lejátszólista beállítások</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="691"/>
        <source>Browser Root</source>
        <translation>Root mappa</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="704"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="276"/>
        <source>About Knowthelist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
